summaryrefslogtreecommitdiffstats
path: root/smb4k/core/smb4kglobal_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/core/smb4kglobal_p.h')
-rw-r--r--smb4k/core/smb4kglobal_p.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/smb4k/core/smb4kglobal_p.h b/smb4k/core/smb4kglobal_p.h
index f0e329d..898d66e 100644
--- a/smb4k/core/smb4kglobal_p.h
+++ b/smb4k/core/smb4kglobal_p.h
@@ -1,5 +1,5 @@
/***************************************************************************
- smb4kglobal_p - This is the private helper class of the Smb4KGlobal
+ smb4kglobal_p - This is the private helper class of the Smb4TDEGlobal
namespace.
-------------------
begin : Di Jul 24 2007
@@ -43,23 +43,23 @@
#include "smb4khomesshareshandler.h"
/**
* This class is a private helper for the Smb4KGlobal namespace.
*
* @author Alexander Reinholdt <dustpuppy@users.berlios.de>
*/
-class Smb4KGlobalPrivate
+class Smb4TDEGlobalPrivate
{
public:
/**
* Constructor
*/
- Smb4KGlobalPrivate();
+ Smb4TDEGlobalPrivate();
/**
* Destructor
*/
- ~Smb4KGlobalPrivate();
+ ~Smb4TDEGlobalPrivate();
/**
* Returns a pointer to the global timer
@@ -43,23 +43,23 @@
#include "smb4khomesshareshandler.h"
/**
- * This class is a private helper for the Smb4KGlobal namespace.
+ * This class is a private helper for the Smb4TDEGlobal namespace.
*
* @author Alexander Reinholdt <dustpuppy@users.berlios.de>